@@ -882,7 +882,7 @@ sub getPngLibrary($@) {
     if (defined($pnglib)) {
         my $default;
 
-        if (-d("/usr/include/png")) {
+        if (-d("/usr/include/libpng")) {
             $default = "/usr/include/libpng";
         } else {
             $default = "default";
