@@ -843,7 +843,12 @@ lzwReadByte(struct decompressor * const decompP) {
                 getCode(decompP->ifP, decompP->codeSize, FALSE);
             decompP->prevcode = decompP->firstcode;
         } while (decompP->firstcode == decompP->clear_code);
-        retval = decompP->firstcode;
+        if (decompP->firstcode == decompP->end_code) {
+            if (!zeroDataBlock)
+                readThroughEod(decompP->ifP);
+            retval = -2;
+        } else
+            retval = decompP->firstcode;
     } else {
         int code;
         code = getCode(decompP->ifP, decompP->codeSize, FALSE);
@@ -942,7 +947,7 @@ readImageData(FILE * const ifP,
                     ypos += 2; break;
                 }
                 
-                if (ypos >= height) {
+                while (ypos >= height) {
                     ++pass;
                     switch (pass) {
                     case 1:
