@@ -407,7 +407,7 @@ meaningful_bits_pgm(FILE *         const ifp,
             pnm_readpnmrow(ifp, xelrow, cols, maxval, format);
             for (x = 0 ; x < cols && mayscale ; x++) {
                 if ((PNM_GET1 (xelrow[x]) & 0xf) * 0x11 
-                    != PNM_GET1 (xelrow[x]))
+                    != (PNM_GET1 (xelrow[x]) & 0xff))
                     mayscale = FALSE;
             }
         }
@@ -421,7 +421,8 @@ meaningful_bits_pgm(FILE *         const ifp,
         for (y = 0 ; y < rows && mayscale ; y++) {
             pnm_readpnmrow(ifp, xelrow, cols, maxval, format);
             for (x = 0 ; x < cols && mayscale ; x++) {
-                if ((PNM_GET1 (xelrow[x])&3) * 0x5 != PNM_GET1 (xelrow[x]))
+	         if ((PNM_GET1 (xelrow[x])&3) * 0x5 != 
+		     (PNM_GET1 (xelrow[x]) & 0xf))
                     mayscale = FALSE;
             }
         }
@@ -436,7 +437,8 @@ meaningful_bits_pgm(FILE *         const ifp,
         for (y = 0 ; y < rows && mayscale ; y++) {
             pnm_readpnmrow(ifp, xelrow, cols, maxval, format);
             for (x = 0 ; x < cols && mayscale ; x++) {
-                if ((PNM_GET1 (xelrow[x])&1) * 0x3 != PNM_GET1 (xelrow[x]))
+	         if ((PNM_GET1 (xelrow[x])&1) * 0x3 !=
+		     (PNM_GET1 (xelrow[x]) & 3))
                     mayscale = FALSE;
             }
         }
@@ -584,7 +586,9 @@ alpha_trans(FILE *     const ifp,
                     }
             }
         }  
-    }
+    } else
+        retval = FALSE;
+
     pnm_freerow(xelrow);
 
     *alpha_can_be_transparency_indexP = retval;
@@ -1363,7 +1367,7 @@ computeColorMap(FILE *         const ifP,
                                                  palette_pnm, &paletteSize, 
                                                  trans_pnm, &transSize);
     
-                        if (transparent != -1)
+                        if (transparent)
                             makeOneColorTransparentInPalette(
                                 transcolor, transexact, 
                                 palette_pnm, paletteSize, trans_pnm, 
@@ -1754,7 +1758,7 @@ convertpnm(FILE * const ifp,
                     force, &pnm_meaningful_bits);
   
   computeColorMap(ifp, imagepos, cols, rows, maxval, format,
-                  force, pfp, alpha, transparent, transcolor, transexact, 
+                  force, pfp, alpha, transparent >= 0, transcolor, transexact, 
                   background, backcolor,
                   alpha_mask, pnm_meaningful_bits,
                   palette_pnm, &palette_size, trans_pnm, &trans_size,
