@@ -326,6 +326,14 @@ BumpPixel()
                           if( cury >= Height ) {
                                 ++Pass;
                                 cury = 4;
+                                if (cury >= Height) {
+                                    ++Pass;
+                                    cury = 2;
+                                    if (cury >= Height) {
+                                        ++Pass;
+                                        cury = 1;
+                                    }
+                                }
                           }
                           break;
 
@@ -334,6 +342,10 @@ BumpPixel()
                           if( cury >= Height ) {
                                 ++Pass;
                                 cury = 2;
+                                if (cury >= Height) {
+                                    ++Pass;
+                                    cury = 1;
+                                }
                           }
                           break;
 
@@ -1016,11 +1028,21 @@ writeGifHeader(FILE * const fp,
 
     {
         /* Write out the Global Color Map */
+        /* Note that the Global Color Map is always a power of two colors
+           in size, but *cmapP could be smaller than that.  So we pad with
+           black.
+        */
         int i;
-        for( i=0; i < ColorMapSize; ++i ) {
-            fputc( cmapP->red[i], fp );
-            fputc( cmapP->green[i], fp );
-            fputc( cmapP->blue[i], fp );
+        for ( i=0; i < ColorMapSize; ++i ) {
+            if ( i < cmapP->cmapsize ) {
+                fputc( cmapP->red[i], fp );
+                fputc( cmapP->green[i], fp );
+                fputc( cmapP->blue[i], fp );
+            } else {
+                fputc( 0, fp );
+                fputc( 0, fp );
+                fputc( 0, fp );
+            }
         }
     }
         
