@@ -844,7 +844,16 @@ static sample
 floatToSample(double const value,
               sample const maxval) {
 
-    return MAX(0, MIN(maxval, (sample)(value + 0.5)));
+    /* Take care here, the conversion of any floating point value <=
+       -1.0 to an unsigned type is _undefined_.  See ISO 9899:1999
+       section 6.3.1.4.  Not only is it undefined it also does the
+       wrong thing in actual practice, EG on Darwin PowerPC (my iBook
+       running OS X) negative values clamp to maxval.  We get negative
+       values because some of the filters (EG catrom) have negative
+       weights.  
+    */
+
+    return MIN(maxval, (sample)(MAX(0.0, (value + 0.5))));
 }
 
 
